@@ -38,7 +38,7 @@ if TYPE_CHECKING:
     from collections.abc import Sequence
     from pathlib import Path
 
-    from griffe._internal.docstrings.parsers import DocstringStyle
+    from griffe._internal.docstrings.parsers import DocstringOptions, DocstringStyle
     from griffe._internal.enumerations import Parser
 
 _TYPING_MODULES: tuple[types.ModuleType, ...]
@@ -60,7 +60,7 @@ def inspect(
     extensions: Extensions | None = None,
     parent: Module | None = None,
     docstring_parser: DocstringStyle | Parser | None = None,
-    docstring_options: dict[str, Any] | None = None,
+    docstring_options: DocstringOptions | None = None,
     lines_collection: LinesCollection | None = None,
     modules_collection: ModulesCollection | None = None,
 ) -> Module:
@@ -95,7 +95,7 @@ def inspect(
         extensions: The extensions to use when inspecting the module.
         parent: The optional parent of this module.
         docstring_parser: The docstring parser to use. By default, no parsing is done.
-        docstring_options: Additional docstring parsing options.
+        docstring_options: Docstring parsing options.
         lines_collection: A collection of source code lines.
         modules_collection: A collection of modules.
 
@@ -127,7 +127,7 @@ class Inspector:
         extensions: Extensions,
         parent: Module | None = None,
         docstring_parser: DocstringStyle | Parser | None = None,
-        docstring_options: dict[str, Any] | None = None,
+        docstring_options: DocstringOptions | None = None,
         lines_collection: LinesCollection | None = None,
         modules_collection: ModulesCollection | None = None,
     ) -> None:
@@ -139,7 +139,7 @@ class Inspector:
             extensions: Extensions to use when inspecting.
             parent: The module parent.
             docstring_parser: The docstring parser to use.
-            docstring_options: The docstring parsing options.
+            docstring_options: Docstring parsing options.
             lines_collection: A collection of source code lines.
             modules_collection: A collection of modules.
         """
@@ -163,7 +163,7 @@ class Inspector:
         self.docstring_parser: DocstringStyle | Parser | None = docstring_parser
         """The docstring parser to use."""
 
-        self.docstring_options: dict[str, Any] = docstring_options or {}
+        self.docstring_options: DocstringOptions = docstring_options or {}
         """The docstring parsing options."""
 
         self.lines_collection: LinesCollection = lines_collection or LinesCollection()
@@ -291,9 +291,9 @@ class Inspector:
                         self.current.set_member(child.name, inspector.current.module)
                 # Otherwise, alias the object.
                 else:
-                    alias = Alias(child.name, target_path)
+                    alias = Alias(child.name, target_path, analysis="dynamic")
                     self.current.set_member(child.name, alias)
-                    self.extensions.call("on_alias", alias=alias, node=node, agent=self)
+                    self.extensions.call("on_alias_instance", alias=alias, node=node, agent=self)
             else:
                 self.inspect(child)
 
@@ -312,6 +312,7 @@ class Inspector:
             docstring=self._get_docstring(node),
             lines_collection=self.lines_collection,
             modules_collection=self.modules_collection,
+            analysis="dynamic",
         )
         self.extensions.call("on_instance", node=node, obj=module, agent=self)
         self.extensions.call("on_module_instance", node=node, mod=module, agent=self)
@@ -342,6 +343,7 @@ class Inspector:
             type_parameters=TypeParameters(*_convert_type_parameters(node.obj, parent=self.current, member=node.name)),
             lineno=lineno,
             endlineno=endlineno,
+            analysis="dynamic",
         )
         self.current.set_member(node.name, class_)
         self.current = class_
@@ -483,6 +485,7 @@ class Inspector:
                 docstring=self._get_docstring(node),
                 lineno=lineno,
                 endlineno=endlineno,
+                analysis="dynamic",
             )
         else:
             obj = Function(
@@ -495,6 +498,7 @@ class Inspector:
                 docstring=self._get_docstring(node),
                 lineno=lineno,
                 endlineno=endlineno,
+                analysis="dynamic",
             )
         obj.labels |= labels
         self.current.set_member(node.name, obj)
@@ -523,6 +527,7 @@ class Inspector:
             type_parameters=TypeParameters(*_convert_type_parameters(node.obj, parent=self.current, member=node.name)),
             docstring=self._get_docstring(node),
             parent=self.current,
+            analysis="dynamic",
         )
         self.current.set_member(node.name, type_alias)
         self.extensions.call("on_instance", node=node, obj=type_alias, agent=self)
@@ -574,6 +579,7 @@ class Inspector:
             value=value,
             annotation=annotation,
             docstring=docstring,
+            analysis="dynamic",
         )
         attribute.labels |= labels
         parent.set_member(node.name, attribute)
@@ -705,10 +711,8 @@ def _convert_type_to_annotation(obj: Any, *, parent: Module | Class, member: str
         _convert_type_to_annotation(arg, parent=parent, member=member) for arg in typing.get_args(obj)
     ]
 
-    # YORE: EOL 3.9: Replace block with lines 2-3.
-    if sys.version_info >= (3, 10):
-        if origin is types.UnionType:
-            return functools.reduce(lambda left, right: ExprBinOp(left, "|", right), args)  # type: ignore[arg-type]
+    if origin is types.UnionType:
+        return functools.reduce(lambda left, right: ExprBinOp(left, "|", right), args)  # type: ignore[arg-type]
 
     origin = _convert_type_to_annotation(origin, parent=parent, member=member)
     if origin is None:
